<?php
/**
 * @file
 * Custom functions for SmartWaiver API.
 */

/**
 * Adds defaults to smartwaiver options
 *
 * @param array $options
 *  Array of query options
 */
function _smartwaiver_query_defaults(&$options) {
  $options['smartwaiver_url'] = SMARTWAIVER_URL;
  $options['api_version'] = SMARTWAIVER_API_VERSION;
  $options['params']['rest_request'] = SMARTWAIVER_API_KEY;
}

/**
 * Builds query URL smartwaiver options
 *
 * @param array $options
 *  Array of query options
 */
function _smartwavier_build_query(&$options) {
  // Get defaults
  _smartwaiver_query_defaults($options);

  // Create URL
  $query_url = $options['smartwaiver_url'] . '/' . $options['api_version'];

  // Add query parameters
  if (!empty($options['params'])) {
    $query_url = url($query_url, array('query' => $options['params']));
  }

  // Set query in options
  $options['query_url'] = $query_url;
}

/**
 * Executes smartwaiver query and returns result
 *
 * @param array $options
 *  Array of query options
 */
function _smartwaiver_execute_query($options) {
  $api_result = simplexml_load_file($options['query_url']);

  if ($options['json_decode']) {
    return json_decode(json_encode($api_result), 1);
  }
  else {
    return $api_result;
  }
}

/**
 * Builds and executes a smartwaiver query
 *
 * @param array $params
 *  Array of parameters to be added to smartwaiver URL
 * @param bool $json_decode
 *  Boolean to determine return type of result
 * @return
 *  XML Element or JSON array with query result
 */
function smartwaiver_run_query($params = array(), $json_decode = FALSE) {
  // Set options
  $options = array(
    'params' => $params,
    'json_decode' => $json_decode,
  );

  // Build the query
  _smartwavier_build_query($options);

  // Execute the query
  return _smartwaiver_execute_query($options);
}
