<?php
/**
 * @file
 * Admin settings SmartWaiver API.
 */

/**
 * Settings form for SmartWaiver API Keys.
 */
function smartwaiver_settings_form($form, &$form_state) {
  $smartwaiver_api_key = variable_get('smartwaiver_api_key');
  if (!isset($smartwaiver_api_key)) {
    $api_key_description = 'API is NOT set. Set API Keys at https://www.smartwaiver.com/m/rest/';
  }
  else {
    $api_key_description = 'API Key is set. Set new API Keys at https://www.smartwaiver.com/m/rest/';
  }

  $form['smartwaiver_api_key'] = array(
    '#type' => 'password',
    '#title' => t('SmartWaiver API Key'),
    '#description' => t($api_key_description),
  );

  $webhook_private_key = variable_get('smartwaiver_webhook_private_key');
  if (!isset($webhook_private_key)) {
    $webhook_key_description = 'Webhook Private Key is NOT set. Set Webhook Private Keys at https://www.smartwaiver.com/m/rest/?webhooks';
  }
  else {
    $webhook_key_description = 'Webhook Private Key is set. Set new Webhook Private Keys at https://www.smartwaiver.com/m/rest/?webhooks';
  }

  $form['smartwaiver_webhook_private_key'] = array(
    '#type' => 'password',
    '#title' => t('SmartWaiver Webhook Private Key'),
    '#description' => t($webhook_key_description),
  );

  $form['submit'] = array(
    '#type' => 'submit',
    '#value' => t('Save'),
  );

  return $form;
}

/**
 * Submit handler for SmartWaiver settings form
 */
function smartwaiver_settings_form_submit($form, &$form_state) {
  if (!empty($form_state['values']['smartwaiver_api_key'])) {
    variable_set('smartwaiver_api_key', $form_state['values']['smartwaiver_api_key']);
  }
  if (!empty($form_state['values']['smartwaiver_webhook_private_key'])) {
    variable_set('smartwaiver_webhook_private_key', $form_state['values']['smartwaiver_webhook_private_key']);
  }
  drupal_set_message(t('The settings have been saved.'));
}

/**
 * Settings form for SmartWaiver list of waivers.
 */
function smartwaiver_list_of_waivers_form($form, &$form_state) {
  // Load in config file
  require_once drupal_get_path('module', 'smartwaiver') . '/smartwaiver.config.php';

  $api_key = SMARTWAIVER_API_KEY;
  if (!isset($api_key) || empty($api_key)) {
    // Configuration has not been completed, display message.
    $form['no_config'] = array(
      '#markup' => '<p>' . t('Your API Key is empty or has not been set. Please visit the <a href="@settings_page">settings page</a> to complete configuration.', array('@settings_page' => url('admin/config/smartwaiver/settings'))),
    );
    return $form;
  }

  // Get list of waiver types
  $params = array(
    'resetapi_listofwaivertypes' => '',
  );
  $waiver_result = smartwaiver_run_query($params);

  if (!isset($waiver_result->waivers->waiver)) {
    // Show error message
    if (isset($waiver_result->error->msg)) {
      $error_msg = $waiver_result->error->msg;
    }
    else {
      $error_msg = '';
    }

    $form['error'] = array(
      '#markup' => '<p>' . t('There was an error processing the request. SmartWaiver Error: @error_msg', array('@error_msg' => $error_msg)),
    );
    return $form;
  }

  $options = array();
  foreach ($waiver_result->waivers->waiver as $waiver) {
    $guid = strval($waiver->guid);
    $title = strval($waiver->title) . ' (GUID: ' . $guid . ')';
    $options[$guid] = $title;
  }

  $form['smartwavier_active_waivers'] = array(
    '#type' => 'checkboxes',
    '#title' => t('Active Waivers'),
    '#description' => t('Select which waivers will trigger the SmartWaiver webhook. The results from these waivers will be available in hook_smartwaiver_webhook_participant()'),
    '#options' => $options,
    '#default_value' => variable_get('smartwavier_active_waivers', array()),
  );

  return system_settings_form($form);
}
